function data = INPUT(filein,fileout)



fid=fopen(filein);
fout=fopen(fileout,'w');

data.ICONV=0;data.INTIAL=0;data.JVEC=1;data.NSSV=0;data.NFLAG=1;

%%     R E A D I N   T H E   I N P U T    D A T A    H E R E
%
Title = textscan(fid,'%q',1);
data.Title=Title{1};
%
%     Read problem and analysis type
%
mod=textscan(fid,'%n %n %n %n',1,'commentStyle', '//');
data.ITYPE=mod{1};data.IGRAD=mod{2};data.ITEM=mod{3};data.NEIGN=mod{4};
if(data.ITEM == 0); data.NEIGN=0;end
if(data.NEIGN ~= 0)
    if(data.ITYPE<=3 && data.NEIGN > 1) 
        fprintf(fout,'  * STABILITY ANALYSIS IS ONLY FOR BENDING OF PLATES*\n');
        error('**** according to the  classical plate theory ****');
    else
        nval=textscan(fid,'%n %n',1,'commentStyle', '//');
        data.NVALU=nval{1};data.NVCTR=nval{2};
    end
end
%
%     Read finite element mesh information
%
ielt=textscan(fid,'%n %n %n %n',1,'commentStyle', '//');
data.IELTYP=ielt{1};data.NPE=ielt{2};data.MESH=ielt{3};data.NPRNT=ielt{4};

if(data.ITYPE >= 3 && data.IELTYP == 0)
    error('**TRIANGULAR ELEMENTS ARE NOT ALLOWED FOR PLATES**')
end
if(data.NPE <= 4)
    data.IEL=1;
else
    data.IEL=2;
end
if(data.MESH~=1)
    nem=textscan(fid,'%n %n ',1,'commentStyle', '//');
    data.NEM=nem{1};data.NNM=nem{2};
    if(data.MESH==0)
%     If mesh CANNOT be generated by the program, read the mesh data in
%     the next three statements
        for N=1:data.NEM
            nem=textscan(fid,'%n ',data.NPE,'commentStyle', '//');
            data.NOD(N,1:data.NPE)=nem{:};
        end
        glxy=textscan(fid,'%n %n',data.NNM,'commentStyle', '//');data.GLXY=[glxy{:,1} glxy{:,2}];
    else
%
%     When mesh is to be generated by the program for more complicated
%     geometries, call MESH2DGeneral (which reads pertinent data there)
%
        [data.GLXY,data.NOD] = MESH2DG(data,fid);
    end
else
%
%     When mesh is to be generated for rectangular domains, call program
%     MESH2DRectangular, which requires the following data:
%
    nxy=textscan(fid,'%n %n',1,'commentStyle', '//');
    data.NX=nxy{1};data.NY=nxy{2};
    x0=textscan(fid,'%n',1,'commentStyle', '//');data.X0=x0{1};
    dx=textscan(fid,'%n',data.NX,'commentStyle', '//');
    y0=textscan(fid,'%n',1,'commentStyle', '//');
    dy=textscan(fid,'%n',data.NY,'commentStyle', '//');data.Y0=y0{1};
    data.DX=dx{:};data.DY=dy{:};
    [data.GLXY,data.NEM,data.NNM,data.NOD] = MESH2DR(data);
end

if (data.ITYPE == 0)
    data.NDF = 1;
else
    if(data.ITYPE >= 3) 
        data.NDF = 3;
    else
        data.NDF = 2;
    end
end

if(data.ITYPE==5); data.NDF=4;end

data.NEQ=data.NNM*data.NDF;
data.NN=data.NPE*data.NDF;

if(data.NEIGN==0)% Compute the half bandwidth of the global coefficient matrix
    data.NHBW=0.0;
    for i=1:data.NEM
        NW=(max(data.NOD(i,:))-min(data.NOD(i,:))+1)*data.NDF;
        if(data.NHBW < NW);data.NHBW=NW;end
    end
else
    data.NHBW=data.NEQ;
end

%
%     Read specified primary and secondary degrees of freedom: node
%     number, local degree of freedom number, and specified value.
%
nspv=textscan(fid,'%n',1,'commentStyle', '//');data.NSPV=nspv{1};
if(data.NSPV~=0)
    ispv=textscan(fid,'%n %n',data.NSPV,'commentStyle', '//');data.ISPV=[ispv{:,1} ispv{:,2}];
    if(data.NEIGN==0) 
        vspv=textscan(fid,' %n',data.NSPV,'commentStyle', '//');data.VSPV=vspv{:};
    end
end

if(data.NEIGN==0)
    nssv=textscan(fid,'%n',1,'commentStyle', '//');data.NSSV=nssv{1};
    if(data.NSSV~=0)
        issv=textscan(fid,'%n %n',data.NSSV,'commentStyle', '//');data.ISSV=[issv{:,1} issv{:,2}];
        vssv=textscan(fid,' %n',data.NSSV,'commentStyle', '//');data.VSSV=vssv{:};
    end
end

fprintf(fout,'%s\n',data.Title{1}');
fprintf(fout,'\n_____________________________________________________________________\n');
fprintf(fout,'\n            OUTPUT  from  program *** FEM2D *** by J. N. REDDY\n');
fprintf(fout,'_____________________________________________________________________\n\n');

if(data.ITYPE==0)
%
%     Heat transfer and like problems:__________________________________
%     Read the coefficients of the differential equation modeled
%     A11 = A10 + A1X*X + A1Y*Y; A22 = A20 + A2X*X + A2Y*Y; A00=CONST.
%
    fprintf(fout,'\n\n         ANALYSIS  OF   A  POISSON/LAPLACE  EQUATION\n');
    a1=textscan(fid,' %n %n %n',1,'commentStyle', '//');
    data.A10=a1{1};data.A1X=a1{2};data.A1Y=a1{3};

    a2=textscan(fid,' %n %n %n',1,'commentStyle', '//');
    data.A20=a2{1};data.A2X=a2{2};data.A2Y=a2{3};

    a0=textscan(fid,' %n ',1,'commentStyle', '//');data.A00=a0{:};
    fprintf(fout,'\n COEFFICIENTS OF THE DIFFERENTIAL EQUATION:\n\n');
    fprintf(fout,'      Coefficient, A10...............=  %12.4e\n',data.A10);
    fprintf(fout,'      Coefficient, A1X...............=  %12.4e\n',data.A1X);
    fprintf(fout,'      Coefficient, A1Y...............=  %12.4e\n',data.A1Y);
    fprintf(fout,'      Coefficient, A20...............=  %12.4e\n',data.A20);
    fprintf(fout,'      Coefficient, A2X...............=  %12.4e\n',data.A2X);
    fprintf(fout,'      Coefficient, A2Y...............=  %12.4e\n',data.A2Y);
	fprintf(fout,'      Coefficient, A00...............=  %12.4e\n',data.A00);
	
    iconv=textscan(fid,' %n ',1,'commentStyle', '//');data.ICONV=iconv{:};
    if(data.ICONV~=0)
        nbe=textscan(fid,' %n ',1,'commentStyle', '//');data.NBE=nbe{:};
        ibn=textscan(fid,'%n %n %n %n %n',data.NBE,'commentStyle', '//');
        data.IBN=ibn{1:data.NBE:end};
        data.INOD=[ibn{2:data.NBE:end} ibn{3:data.NBE:end}];
        data.BETA=ibn{4:data.NBE:end};data.TINF=ibn{5:data.NBE:end};
        fprintf(fout,'\n     CONVECTIVE HEAT TRANSFER DATA:\n\n');
        fprintf(fout,'       Number of elements with convection, NBE .=   %d\n',length(data.IBN));
        fprintf(fout,'       Elements, their LOCAL nodes and convective\n');
        fprintf(fout,'       heat transfer data:\n');
        fprintf(fout,'       Ele. No.      End Nodes        Film Coeff.      T-Infinity\n\n');
	    fprintf(fout,'         %2d          %2d  %2d           %8.5e     %8.5e \n',[data.IBN,data.INOD,data.BETA data.TINF]'); 
    end
else
    if(data.ITYPE==1)% Viscous incompressible flows:
        fprintf(fout,'\n A VISCOUS INCOMPRESSIBLE FLOW IS ANALYZED');
        vis=textscan(fid,' %n %n',1,'commentStyle', '//');
        data.VISCSITY=vis{1};data.PENALTY=vis{2};
        fprintf(fout,'\n\n PARAMETERS OF THE FLUID FLOW PROBLEM:\n\n');
        fprintf(fout,'       Viscosity of the fluid, VISCSITY ........=  %12.4e\n',data.VISCSITY);
        fprintf(fout,'       Penalty parameter, PENALTY...............=  %12.4e\n',data.PENALTY);
    else
        if(data.ITYPE==2) % Plane elasticity problems:
            lnstrs=textscan(fid,' %n ',1,'commentStyle', '//');data.LNSTRS=lnstrs{1};
            fprintf(fout,'\n A 2-D ELASTICITY PROBLEM IS ANALYZED');
            young=textscan(fid,' %n %n %n %n %n ',1,'commentStyle', '//');
            data.E1=young{1};data.E2=young{2};data.ANU12=young{3};
            data.G12=young{4};data.THKNS=young{5};
            fprintf(fout,'\n\n MATERIAL PROPERTIES OF THE SOLID ANALYZED:\n\n');
		    fprintf(fout,'       Thickness of the body, THKNS .......=  %12.4e\n',data.THKNS);
            fprintf(fout,'       Modulus of Elasticity, E1...........=  %12.4e\n',data.E1);
            fprintf(fout,'       Modulus of Elasticity, E2...........=  %12.4e\n',data.E2);
            fprintf(fout,'       Modulus of Elasticity, ANU12........=  %12.4e\n',data.ANU12);
            fprintf(fout,'       Shear modulus, G12..................=  %12.4e\n',data.G12);
%
%     Compute the material coefficient matrix, CMAT(I,J), I,J=1,2,3.
%
		    data.E3=data.E2;data.ANU23=data.ANU12;data.ANU13=data.ANU12;
	        data.ANU32=data.ANU23*(data.E3/data.E2);
	        data.ANU31=data.ANU13*(data.E2/data.E1);
			data.ANU21=data.ANU12*(data.E2/data.E1);
		    data.CMAT(3,3)=data.G12*data.THKNS;
            if(data.LNSTRS==0) % Plane strain  (ANU23 = ANU12)
                fprintf(fout,'\n\n    ***PLANE STRAIN assumption is selected by user**\n\n');
                data.S0=(1-data.ANU23*data.ANU32-data.ANU12*data.ANU21-...
                         data.ANU13*data.ANU31-2*data.ANU12*data.ANU23*data.ANU31);
		        data.CMAT(1,1)=data.THKNS*data.E1*(1-data.ANU23*data.ANU32)/data.S0;
			    data.CMAT(2,2)=data.THKNS*data.E2*(1-data.ANU13*data.ANU31)/data.S0;
		        data.CMAT(1,2)=data.THKNS*data.E2*(data.ANU12+data.ANU13*data.ANU32)/data.S0;
            else %     Plane stress
                fprintf(fout,'\n\n    ***PLANE STRESS assumption is selected by user**\n\n');
			    DENOM=1.0-data.ANU12*data.ANU21;
		        data.CMAT(1,1)=data.THKNS*data.E1/DENOM;
		        data.CMAT(1,2)=data.ANU21*data.CMAT(1,1);
		        data.CMAT(2,2)=data.CMAT(1,1)*(data.E2/data.E1);
            end
        else%     Plate bending problems:
            fprintf(fout,'\n\n   A  PLATE   BENDING   PROBLEM  IS  ANALYZED \n\n');
            if(data.ITYPE==3)
                fprintf(fout,'*** using the shear deformation theory ***');
            else
                fprintf(fout,'*** using the classical plate theory ***');
            end
            young=textscan(fid,' %n %n %n %n %n %n %n',1,'commentStyle', '//');
		    data.E1=young{1};data.E2=young{2};data.ANU12=young{3};
            data.G12=young{4};data.G13=young{5};data.G23=young{6};
            data.THKNS=young{7};
            fprintf(fout,'\n\n     MATERIAL PROPERTIES OF THE SOLID ANALYZED:\n\n');
		    fprintf(fout,'       Thickness of the body, THKNS .......=  %12.4e\n',data.THKNS);
            fprintf(fout,'       Modulus of Elasticity, E1...........=  %12.4e\n',data.E1);
            fprintf(fout,'       Modulus of Elasticity, E2...........=  %12.4e\n',data.E2);
            fprintf(fout,'       Modulus of Elasticity, ANU12........=  %12.4e\n',data.ANU12);
            fprintf(fout,'       Shear modulus, G12..................=  %12.4e\n',data.G12);
            fprintf(fout,'       Shear modulus, G13..................=  %12.4e\n',data.G13);
		    fprintf(fout,'       Shear modulus, G23..................=  %12.4e\n',data.G23); 
		    data.ANU21=data.ANU12*data.E2/data.E1;
		    DENOM=1.0-data.ANU12*data.ANU21;
		    data.CMAT(1,1)=data.THKNS^3*data.E1/DENOM/12;
		    data.CMAT(1,2)=data.ANU21*data.CMAT(1,1);
		    data.CMAT(2,2)=data.E2*data.CMAT(1,1)/data.E1;
		    data.CMAT(3,3)=data.G12*data.THKNS^3/12;
		    data.SCF=5/6;
		    data.C44=data.SCF*data.G23*data.THKNS;
		    data.C55=data.SCF*data.G13*data.THKNS;
        end
        data.CMAT(2,1)=data.CMAT(1,2);
	    data.CMAT(3,1)=data.CMAT(1,3);
        data.CMAT(3,2)=data.CMAT(2,3);
    end
end

if(data.NEIGN==0)
    f0=textscan(fid,' %n %n %n',1,'commentStyle', '//');
    data.F0=f0{1};data.FX=f0{2};data.FY=f0{3};
    fprintf(fout,'\n CONTINUOUS SOURCE COEFFICIENTS:\n\n');
    fprintf(fout,'       Coefficient, F0...............=  %12.4e\n',data.F0);
    fprintf(fout,'       Coefficient, FX...............=  %12.4e\n',data.FX);
    fprintf(fout,'       Coefficient, FY...............=  %12.4e\n',data.FY);
end

if(data.ITEM~=0)
    c0=textscan(fid,' %n %n %n',1,'commentStyle', '//');
    data.C0=c0{1};data.CX=c0{2};data.CY=c0{3};
    if(data.ITYPE > 1)
        if(data.ITYPE==2)
	   	    data.C0=data.THKNS*data.C0;
	   	    data.CX=data.THKNS*data.CX;
            data.CY=data.THKNS*data.CY;
        else
            if(data.NEIGN <= 1)
                data.C0=data.THKNS*data.C0;
		        data.CX=data.THKNS^2*data.C0/12;
		        data.CY=data.CX;
            end
        end
    end

    if(data.NEIGN~=0)
        fprintf(fout,'\n\n   ******An EIGENVALUE PROBLEM is analyzed******\n');
	    fprintf(fout,'     PARAMETERS OF THE DYNAMIC ANALYSIS:\n\n');
        fprintf(fout,'     Coefficient, C0................=%12.4e\n',data.C0);
        fprintf(fout,'     Coefficient, CX................=%12.4e\n',data.CX);
        fprintf(fout,'     Coefficient, CY................=%12.4e\n',data.CY);
    else
        fprintf(fout,'\n\n   ******A TRANSIENT PROBLEM is analyzed******\n');
	    fprintf(fout,'\n PARAMETERS OF THE DYNAMIC ANALYSIS:\n\n');
        fprintf(fout,'       Coefficient, C0.................................= %12.4e\n',data.C0);
        fprintf(fout,'       Coefficient, CX.................................= %12.4e\n',data.CX);
        fprintf(fout,'       Coefficient, CY.................................= %12.4e\n',data.CY);
%
%     Read the necessary data for time-dependent problems
%
        ntime=textscan(fid,' %n %n %n %n',1,'commentStyle', '//');
	    data.NTIME=ntime{1};data.NSTP=ntime{2};
        data.INTVL=ntime{3};data.INTIAL=ntime{4};
	    if(data.INTVL <= 0);data.INTVL=1;end
            dt=textscan(fid,' %n %n %n %n',1,'commentStyle', '//');
            data.DT=dt{1};data.ALFA=dt{2};data.GAMA=dt{3};data.EPSLN=dt{4};
            data.A1=data.ALFA*data.DT;
            data.A2=(1-data.ALFA)*data.DT;
            fprintf(fout,'       Time increment used, DT.........................= %12.4e\n ',data.DT);
            fprintf(fout,'       Parameter, ALFA................................= %12.4e\n ',data.ALFA);
            fprintf(fout,'       Parameter, GAMA................................= %12.4e\n ',data.GAMA);
            fprintf(fout,'       No of Time steps used, NTIME...................=   %d\n ',data.NTIME);
            fprintf(fout,'       Time step at which load is removed, NSTP.......=   %d\n ',data.NSTP);
            fprintf(fout,'       Time interval at which soln. is printed, INTVL.=   %d\n ',data.INTVL);
            if(data.ITEM==1)
                if(data.NSSV~=0)
                    data.VSSV=data.VSSV*data.DT;
                end
                if(data.INTIAL~=0)
                    glu=textscan(fid,' %n ',data.NEQ,'commentStyle', '//');
                    data.GLU=glu{:};
                else
                    data.GLU=zeros(1,data.NEQ);
                end
            else
                DT2=data.DT^2;
                data.A3=2/data.GAMA/DT2;
                data.A4=data.A3*data.DT;
                data.A5=1/data.GAMA-1;
                if(data.INTIAL~=0)
                    glu=textscan(fid,' %n ',data.NEQ,'commentStyle', '//');
                    glv=textscan(fid,' %n ',data.NEQ,'commentStyle', '//');
                    data.GLU=glu{:};
                    data.GLV=glv{:};
                    data.GLA=zeros(1,data.NEQ);
                else
                    data.GLU=zeros(1,data.NEQ);
                    data.GLV=zeros(1,data.NEQ);
                    data.GLA=zeros(1,data.NEQ);

                end
            end
            nodep=textscan(fid,' %n %n %n %n',1,'commentStyle', '//');
            data.NODEP=nodep{1};data.NDFP=nodep{2};
            data.SCALET=nodep{3};data.SCALEU=nodep{4};
    end
else
    fprintf(fout,'\n\n   ******* A STEADY-STATE PROBLEM is analyzed ******\n\n');
end

%%     *****     E N D   O F   T H E    D A T A   I N P U T       *****
    
if(data.IELTYP==0)
    fprintf(fout,'\n   *** A mesh of   TRIANGLES    is chosen by user ***\n');
else
    fprintf(fout,'\n   *** A mesh of QUADRILATERALS is chosen by user ***\n');
end

fprintf(fout,'\n\n FINITE ELEMENT MESH INFORMATION:\n\n');
fprintf(fout,'       Element type: 0 = Triangle; >0 = Quad.).........=  %d\n',data.IELTYP);
fprintf(fout,'       Number of nodes per element, NPE ...............=  %d\n',data.NPE);
fprintf(fout,'       No. of primary deg. of freedom/node, NDF........=  %d\n',data.NDF);
fprintf(fout,'       Number of elements in the mesh, NEM ............=  %d\n',data.NEM);
fprintf(fout,'       Number of nodes in the mesh, NNM ...............=  %d\n',data.NNM);
fprintf(fout,'       Number of equations to be solved, NEQ ..........=  %d\n',data.NEQ);
fprintf(fout,'       Half bandwidth of the matrix GLK, NHBW .........=  %d\n',data.NHBW);

if(data.MESH==1) 
    fprintf(fout,'       Mesh subdivisions, NX and NY ...................=  %d    %d\n\n',data.NX,data.NY);
end
fprintf(fout,'       No. of specified PRIMARY variables, NSPV........=  %d\n',data.NSPV);
if(data.NSSV~=0)
    fprintf(fout,'       No. of speci. SECONDARY variables, NSSV.........=  %d\n',data.NSSV);
	fprintf(fout,'\n       Node        DOF         value\n');
    fprintf(fout,'  %8d   %8d    %14.5e \n',[data.ISSV, data.VSSV]');
end
%
if(data.NPRNT==1)
    fprintf(fout,'Connectivity Matrix, [NOD]\n\n');
    fmt = [repmat('%4d ', 1, size(data.NOD,2)), '%4d\n'];
    fprintf(fout,fmt,[(1:data.NEM)' data.NOD]');
    
% % % 	   DO 100 I=1,NEM
% % % %   100    WRITE(ITT,900) I,(NOD(I,J),J=1,NPE)
end
%
fprintf(fout,'\n\n  _______________________________________________________________\n\n');
fprintf(fout,'  Node    x-ccord      y-coord   Speci. primart & secondary\n');
fprintf(fout,'                                variables (0, unspec.; >0, spec.)\n');
fprintf(fout,'\n                                 Primary DOF      Secondary DOF \n');
fprintf(fout,'  _______________________________________________________________\n');

for IM=1:data.NNM
    data.IBP=zeros(1,data.NDF);
    data.IBS=zeros(1,data.NDF);
    if(data.NSPV~=0)
        for JP=1:data.NSPV
            data.NODE=data.ISPV(JP,1);
            data.NDOF=data.ISPV(JP,2);
            if(data.NODE==IM);data.IBP(data.NDOF)=data.NDOF;end
        end
    end
    if(data.NSSV~=0)
        for JS=1:data.NSSV
           data.NODE=data.ISSV(JS,1);
           data.NDOF=data.ISSV(JS,2);
           if(data.NODE==IM); data.IBS(data.NDOF)=data.NDOF;end
        end
    end
    switch data.NDF
        case 1
            fprintf(fout,'   %2d   %12.4e %12.4e      %d              %d\n',IM,data.GLXY(IM,:),data.IBP,data.IBS);
        case 2
            fprintf(fout,'   %2d  %12.4e  %12.4e   %d  %d             %d  %d\n',IM,data.GLXY(IM,:),data.IBP,data.IBS);
        case 3
            fprintf(fout,'   %2d  %12.4e  %12.4e  %d %d %d      %d %d %d\n',IM,data.GLXY(IM,:),data.IBP,data.IBS);
        otherwise
            fprintf(fout,'   %2d  %12.4e  %12.4e %d %d  %d %d   %d %d %d %d\n',IM,data.GLXY(IM,:),data.IBP,data.IBS);
    end
end
fprintf(fout,'  ____________________________________________________________\n');
%
%     Define the polynomial degree and number of integration points
%     (based on the assumed variation of the coefficients AX, BX, etc.)
%
data.IPDR = data.IEL;
data.NIPR = data.IPDR+data.IEL-1;
if(data.IELTYP==0)
    if(data.ITYPE==0)
        data.IPDF = 2*data.IEL+1;
	    data.NIPF = data.IPDF+data.IEL;
    else
        if(data.ITEM~=0)
            data.IPDF = 2*data.IEL+1;
		    data.NIPF = data.IPDF+data.IEL;
        else
            data.IPDF = data.IEL+1;
		    data.NIPF = data.IPDF+1;
        end
    end
    data.ISTR = 1;
	data.NSTR = 1;
    fprintf(fout,'\n NUMERICAL INTEGRATION DATA:\n');
    fprintf(fout,'\n     Full Integration polynomial degree, IPDF =  %d',data.IPDF);
    fprintf(fout,'\n     Number of full integration points,  NIPF =  %d',data.NIPF);
    fprintf(fout,'\n     Reduced Integration polynomial deg.,IPDR =  %d',data.IPDR);
    fprintf(fout,'\n     No.  of reduced integration points, NIPR =  %d',data.NIPR);
    fprintf(fout,'\n     Integ. poly. deg. for stress comp., ISTR =  %d',data.ISTR);
    fprintf(fout,'\n     No. of integ. pts. for stress comp.,NSTR =  %d\n\n',data.NSTR);
else
    if(data.ITYPE >= 4)
        data.IPDF = 4;
	    data.ISTR = 2;
    else
        data.IPDF = data.IEL+1;
	    data.ISTR = data.IEL;
    end
	fprintf(fout,'\n\n  NUMERICAL INTEGRATION DATA:\n');
    fprintf(fout,'\n Full quadrature (IPDF x IPDF) rule, IPDF =  %d',data.IPDF);
    fprintf(fout,'\n Reduced quadrature (IPDR x IPDR),   IPDR =  %d',data.IPDR);
    fprintf(fout,'\n Quadrature rule used in postproc.,  ISTR =  %d\n\n\n',data.ISTR);
end


plot=textscan(fid,' %n',1,'commentStyle', '//');data.PLOT=plot{1};

end
